from flask import render_template, session, abort, request, redirect, url_for, current_app, flash
from flask_login import login_required
from . import system
from .. import db
from ..email import send_email

from flask_sqlalchemy import get_debug_queries





@system.route('/userlist', methods=['GET', 'POST'])
@login_required
def userlist():
    """
    获取用户列表
    :return:
    """

    return render_template('bey/system/users.html')





from flask import Flask
from flask_bootstrap import Bootstrap
from flask_debugtoolbar import DebugToolbarExtension
from flask_mail import Mail
from flask_moment import Moment
from flask_sqlalchemy import SQLAlchemy
from flask_login import LoginManager


from config import config


__version__="v1.0.10"


bootstrap = Bootstrap()
mail = Mail()
moment = Moment()
db = SQLAlchemy()


login_manager = LoginManager()
login_manager.session_protection = 'strong'
login_manager.login_view = 'auth.login'
login_manager.login_message = u"请登录系统后进行操作！"
login_manager.login_message_category = "info"


def create_app(config_name):

    app = Flask(__name__)
    app.config.from_object(config[config_name])
    config[config_name].init_app(app)

    bootstrap.init_app(app)
    mail.init_app(app)
    moment.init_app(app)
    db.init_app(app)
    db.app = app

    toolbar = DebugToolbarExtension()
    toolbar.init_app(app)

    login_manager.init_app(app)






    from .main import main as main_blueprint
    app.register_blueprint(main_blueprint, url_prefix='/main')

    from .auth import auth as auth_blueprint
    app.register_blueprint(auth_blueprint, url_prefix='/auth')

    from .system import system as auth_blueprint
    app.register_blueprint(auth_blueprint, url_prefix='/system')

    from .api_1_0 import api as api_1_0_blueprint
    app.register_blueprint(api_1_0_blueprint, url_prefix='/api/v1.0')



    return app



#!/usr/bin/env python
# -*- coding: utf-8 -*-

' module description'
import json

from flask import request, jsonify, current_app
from flask_restful import Resource

from app.auth.models import CommonUserInfo

__author__ = 'Andrew Wen'

todos = {}

class CommonUserInfoListApi(Resource):
    def get(self):

        #查询字符串
        filters=set()

        #构建查询条件
        user_name = request.args.get('name')

        if user_name :filters.add(CommonUserInfo.login_account.contains(user_name))


        #获取查询页
        page = request.args.get('page', 1, type=int)





        pagination = CommonUserInfo.query.filter(*filters).order_by(CommonUserInfo.id.desc()).paginate(
            page, per_page=current_app.config['FLASKY_POSTS_PER_PAGE'],
            error_out=False)





        return jsonify({
            'items': [user.to_json() for user in pagination.items],
            'page': pagination.page,
            'prev_num': pagination.prev_num,
            'next_num': pagination.next_num,
            'has_next' :pagination.has_next, #如果有下一页，返回True
            'has_prev': pagination.has_prev, #如果有上一页，返回True
            'pages': pagination.pages, #查询得到的总页数
            'per_page': pagination.per_page, #每页显示的记录数量
            'total': pagination.total,
            'iter_pages':[pages for pages in pagination.iter_pages(left_edge = 2 ,left_current=2,right_current=3,right_edge=2)]

        })


    def post(self):



        #构建查询条件
        login_account = request.form['login_account']



        return jsonify({
            'result': login_account,
            'msg':'新增成功'
        })


class CommonUserInfoApi(Resource):
    def get(self,id):
        """
        获得单对象
        :param id:
        :return:
        """



        #查询字符串
        filters=set()

        #构建查询条件
        user_name = request.args.get('name')

        if user_name :filters.add(CommonUserInfo.login_account.contains(user_name))


        #获取查询页
        page = request.args.get('page', 1, type=int)

        #===



        pagination = CommonUserInfo.query.filter(*filters).order_by(CommonUserInfo.id.desc()).paginate(
            page, per_page=current_app.config['FLASKY_POSTS_PER_PAGE'],
            error_out=False)





        return jsonify({
            'items': [user.to_json() for user in pagination.items],
            'page': pagination.page,
            'prev_num': pagination.prev_num,
            'next_num': pagination.next_num,
            'has_next' :pagination.has_next, #如果有下一页，返回True
            'has_prev': pagination.has_prev, #如果有上一页，返回True
            'pages': pagination.pages, #查询得到的总页数
            'per_page': pagination.per_page, #每页显示的记录数量
            'total': pagination.total,
            'iter_pages':[pages for pages in pagination.iter_pages(left_edge = 2 ,left_current=2,right_current=3,right_edge=2)]

        })

    def put(self, id):
        """
        更新对象
        :param id:
        :return:
        """

        login_account = request.form['login_account']


        return jsonify({
            'result': id,
            'login_account':login_account,
            'msg': '修改成功'
        })


    def delete(self, id):
        """
        删除对象
        :param id:
        :return:
        """




        return jsonify({
            'result': id,
            'msg': '删除成功'
        })





#!/usr/bin/env python
# -*- coding: utf-8 -*-

' module description'
import pexpect

__author__ = 'Andrew Wen'


import paramiko





def ssh_cmd(ip,username, passwd, cmd):

    ret = -1

    ssh = pexpect.spawn('ssh %s@%s "%s"' % (username,ip, cmd))

    try:

        i = ssh.expect(['password:', 'continue connecting (yes/no)?'], timeout=50)

        if i == 0 :

            ssh.sendline(passwd)

        elif i == 1:

            ssh.sendline('yes\n')

            ssh.expect('password: ')

            ssh.sendline(passwd)

        ssh.sendline(cmd)

        r = ssh.read()

        print(r),

        ret = 0

    except pexpect.EOF:

        print("EOF")

        ssh.close()

        ret = -1

    except pexpect.TIMEOUT:

        print("TIMEOUT")

        ssh.close()

        ret = -2
    return ret




def sshclient_execmd(hostname, port, username, password, execmd):

    paramiko.util.log_to_file("paramiko.log")

    try:

        s = paramiko.SSHClient()
        s.set_missing_host_key_policy(paramiko.AutoAddPolicy())

        s.connect(hostname=hostname, port=port, username=username, password=password)
        stdin, stdout, stderr = s.exec_command(execmd)
        #stdin.write("Y")  # Generally speaking, the first connection, need a simple interaction.

        print(str(stdout.read(), encoding="utf-8")),

        s.close()


    except Exception:

        print("error")

def main():
    hostname = '192.168.9.51'
    port = 22
    username = 'root'
    password = '123456'
    execmd = 'docker ps -a'

    sshclient_execmd(hostname, port, username, password, execmd)

    #ssh_cmd(hostname, username, password, execmd)


if __name__ == "__main__":
    main()



from flask_wtf import FlaskForm
from wtforms import StringField, PasswordField, BooleanField, SubmitField
from wtforms.validators import Required, Length, Email, Regexp, EqualTo
from wtforms import ValidationError

from app.auth.models import CommonUserInfo


class LoginForm(FlaskForm):
    email = StringField('Email', validators=[Required(), Length(1, 64),
                                             Email()])
    password = PasswordField('Password', validators=[Required()])
    remember_me = BooleanField('Keep me logged in')
    submit = SubmitField('Log In')


class RegistrationForm(FlaskForm):
    email = StringField('Email', validators=[Required(), Length(1, 64),
                                           Email()])
    login_account = StringField('Username', validators=[
        Required(), Length(1, 64), Regexp('^[A-Za-z][A-Za-z0-9_.]*$', 0,
                                          'Usernames must have only letters, '
                                          'numbers, dots or underscores')])
    password = PasswordField('Password', validators=[
        Required(), EqualTo('password2', message='Passwords must match.')])
    password2 = PasswordField('Confirm password', validators=[Required()])
    submit = SubmitField('注册')

    def validate_email(self, field):
        if CommonUserInfo.query.filter_by(email=field.data).first():
            raise ValidationError('Email already registered.')

    def validate_username(self, field):
        if CommonUserInfo.query.filter_by(login_account=field.data).first():
            raise ValidationError('Username already in use.')


class ChangePasswordForm(FlaskForm):
    old_password = PasswordField('Old password', validators=[Required()])
    password = PasswordField('New password', validators=[
        Required(), EqualTo('password2', message='Passwords must match')])
    password2 = PasswordField('Confirm new password', validators=[Required()])
    submit = SubmitField('Update Password')


class PasswordResetRequestForm(FlaskForm):
    email = StringField('Email', validators=[Required(), Length(1, 64),
                                             Email()])
    submit = SubmitField('Reset Password')


class PasswordResetForm(FlaskForm):
    email = StringField('Email', validators=[Required(), Length(1, 64),
                                             Email()])
    password = PasswordField('New Password', validators=[
        Required(), EqualTo('password2', message='Passwords must match')])
    password2 = PasswordField('Confirm password', validators=[Required()])
    submit = SubmitField('Reset Password')

    def validate_email(self, field):
        if CommonUserInfo.query.filter_by(email=field.data).first() is None:
            raise ValidationError('Unknown email address.')


class ChangeEmailForm(FlaskForm):
    email = StringField('New Email', validators=[Required(), Length(1, 64),
                                                 Email()])
    password = PasswordField('Password', validators=[Required()])
    submit = SubmitField('Update Email Address')

    def validate_email(self, field):
        if CommonUserInfo.query.filter_by(email=field.data).first():
            raise ValidationError('Email already registered.')



from flask import Blueprint
from flask_restful import Api


from app.api_1_0.respful import CommonUserInfoListApi, CommonUserInfoApi

api = Blueprint('api', __name__)
rest_api = Api(api, catch_all_404s=True)


rest_api.add_resource(CommonUserInfoListApi, '/commonuserinfos',endpoint = 'commonuserinfos')
rest_api.add_resource(CommonUserInfoApi, '/commonuserinfo/<int:id>',endpoint = 'commonuserinfo')





from lib2to3.pytree import Base

from flask_login import UserMixin, AnonymousUserMixin
from sqlalchemy import Table, Column, Integer, ForeignKey
from werkzeug.security import generate_password_hash, check_password_hash
from itsdangerous import TimedJSONWebSignatureSerializer as Serializer

from datetime import datetime
from flask import current_app, request, url_for

from app import db, login_manager

#用户角色多对多关系表
user_role_mapper = db.Table('user_role_mapper',
                         db.Column('user_id', db.Integer, db.ForeignKey('common_user_info.id') , nullable=False, primary_key=True),
                         db.Column('role_id', db.Integer, db.ForeignKey('common_role_info.id') , nullable=False, primary_key=True)
                         )





class CommonUserInfo(UserMixin,db.Model):
    """
    用户表
    """
    __tablename__ = 'common_user_info'
    id = db.Column(db.Integer, primary_key=True)
    #账户
    login_account = db.Column(db.String(64),unique=True)
    #密码
    login_password = db.Column(db.String(128))
    #邮箱
    email = db.Column(db.String(64))
    #性别
    user_gender = db.Column(db.Integer)
    #真实名称
    user_name = db.Column(db.String(64))
    #用户编号
    user_no = db.Column(db.String(64))
    #所属组织机构
    user_org = db.Column(db.Integer)


    roles = db.relationship('CommonRoleInfo',
                              secondary=user_role_mapper,
                              lazy='dynamic')

    #extend
    # 真实名称
    icon = db.Column(db.String(64))

    #最后登录时间
    last_login=db.Column(db.DateTime(), default=datetime.utcnow)

    #用户状态
    status = db.Column(db.Integer)
    #操作人
    operate_user_id=db.Column(db.Integer)
    #操作时间
    operate_time = db.Column(db.DateTime(), default=datetime.utcnow)


    def __repr__(self):
        return '<common_user_info %r>' % self.login_account

    @property
    def password(self):
        raise AttributeError('password is not a readable attribute')

    @password.setter
    def password(self, password):
        self.login_password = generate_password_hash(password)

    def verify_password(self, password):
        """
        密码验证方法
        :param password: 需要验证的密码
        :return:
        """
        return check_password_hash(self.login_password, password)

    @login_manager.user_loader
    def load_user(user_id):
        return CommonUserInfo.query.get(int(user_id))

    def to_json(self):
        json = {
            'id' :self.id,
            'login_account' : self.login_account,


            # 邮箱
            'email' : self.email,
            # 性别
            'user_gender' : self.user_gender,
            # 真实名称
            'user_name' : self.user_name,
            # 用户编号
            'user_no' : self.user_no,
            # 所属组织机构
            'user_org' : self.user_org,

            # 真实名称
            'icon' : self.icon,
            # 最后登录时间
            'last_login' : self.last_login,
            # 用户状态
            'status' : self.status,
            # 操作人
            'operate_user_id' : self.operate_user_id,
            # 操作时间
            'operate_time' : self.operate_time
        }

        return json

    @staticmethod
    def generate_fake(count=100):
        from sqlalchemy.exc import IntegrityError

        from random import seed
        import forgery_py
        seed()
        for i in range(count):
            u = CommonUserInfo(email=forgery_py.internet.email_address(),
                               login_account=forgery_py.internet.user_name(True),
                                password=forgery_py.lorem_ipsum.word(),
                               icon="images/2.jpg"
                                )
            db.session.add(u)
            try:
                db.session.commit()
            except IntegrityError:
                db.session.rollback()






class CommonRoleInfo(db.Model):
    """
        角色表
    """
    __tablename__ = 'common_role_info'
    id = db.Column(db.Integer, primary_key=True)
    #角色代码
    role_code = db.Column(db.String(64), unique=True)
    #角色名称
    role_name = db.Column(db.String(64), unique=True)
    #角色顺序
    role_order=db.Column(db.Integer)
    #备注
    role_remark=db.Column(db.Text)
    # 用户状态
    status = db.Column(db.Integer)
    # 操作人
    operate_user_id = db.Column(db.Integer)
    # 操作时间
    operate_time = db.Column(db.DateTime(), default=datetime.utcnow)



    def __repr__(self):
        return '<common_role_info %r>' % self.role_name





class CommonOrgInfo(db.Model):
    """
        组织机构表
    """
    __tablename__ = 'common_org_info'
    id = db.Column(db.Integer, primary_key=True)
    #组织机构代码
    org_code = db.Column(db.String(64), unique=True)
    #组织机构全称
    org_fullname = db.Column(db.String(64), unique=True)
    # 组织机构名称
    org_name = db.Column(db.String(64), unique=True)

    #顺序
    org_order=db.Column(db.Integer)
    #父节点编号
    org_pid = db.Column(db.Integer)

    #备注
    role_remark=db.Column(db.Text)

    # 状态
    status = db.Column(db.Integer)
    # 操作人
    operate_user_id = db.Column(db.Integer)
    # 操作时间
    operate_time = db.Column(db.DateTime(), default=datetime.utcnow)





    def __repr__(self):
        return '<common_org_info %r>' % self.role_name





class CommonMenuInfo(db.Model):
    """
        菜单表
    """
    __tablename__ = 'common_menu_info'
    id = db.Column(db.Integer, primary_key=True)
    #菜单样式
    menu_cls = db.Column(db.String(64), unique=True)
    #菜单代码
    menu_code = db.Column(db.String(64), unique=True)

    #菜单级别
    menu_level=db.Column(db.Integer)
    #菜单名称
    menu_name=db.Column(db.String(64))
    #菜单导航
    menu_nav=db.Column(db.String(64))
    #菜单排序
    menu_order=db.Column(db.Integer)
    #父节点
    menu_pid=db.Column(db.String(64))
    #备注
    menu_remark=db.Column(db.String(64))
    #所属系统
    menu_sysid=db.Column(db.String(64))
    #类别
    menu_type=db.Column(db.Integer)
    #url
    menu_url=db.Column(db.String(64))

    # 状态
    status = db.Column(db.Integer)
    # 操作人
    operate_user_id = db.Column(db.Integer)
    # 操作时间
    operate_time = db.Column(db.DateTime(), default=datetime.utcnow)



    def __repr__(self):
        return '<common_org_info %r>' % self.role_name



from flask import render_template, redirect, request, url_for, flash, current_app
from flask_login import login_user, logout_user, login_required, \
    current_user

from app.auth.forms import RegistrationForm
from app.auth.models import CommonUserInfo
from . import auth
from .. import db



#
# @auth.before_app_request
# def before_request():
#     if current_user.is_authenticated:
#         current_user.ping()
#         if not current_user.confirmed \
#                 and request.endpoint \
#                 and request.endpoint[:5] != 'auth.' \
#                 and request.endpoint != 'static':
#             return redirect(url_for('auth.unconfirmed'))

@auth.before_app_request
def before_request():
    pass
    current_app.logger.warning(current_user)
    # if not current_user.is_authenticated:
    #     flash('用户名或密码错误，请重新登录！', 'danger')
    #     return redirect(url_for('auth.login'))
#
#
# @auth.route('/unconfirmed')
# def unconfirmed():
#     if current_user.is_anonymous or current_user.confirmed:
#         return redirect(url_for('main.index'))
#     return render_template('auth/unconfirmed.html')
#

@auth.route('/login', methods=['GET', 'POST'])
def login():
    """
       登录方法
       :return:
       """
    if request.method == 'POST':

        user = CommonUserInfo.query.filter_by(login_account=request.form['login_account']).first()

        current_app.logger.warning("===登录日志===")

        if user is not None and user.verify_password(request.form['password']):
            login_user(user, True)
            return redirect(url_for('main.index'))

        else:
            flash('用户名或密码错误，请重新登录！', 'warning')

            return redirect(request.args.get('next') or url_for('auth.login'))

    #
    #
    #
    # if user is not None and user.verify_password(request.form['password']):
    #     login_user(user, True)
    #     return redirect(request.args.get('next') or url_for('main.index'))
    #     flash('Invalid username or password.')
    return render_template('auth/login.html')


@auth.route('/logout')
@login_required
def logout():
    logout_user()
    flash('系统注销成功！','success')
    return redirect(url_for('auth.login'))




@auth.route('/register', methods=['GET', 'POST'])
def register():
    """
    用户注册
    :return:
    """
    form = RegistrationForm()
    if form.validate_on_submit():
        user = CommonUserInfo(email=form.email.data,
                    login_account=form.login_account.data,
                    password=form.password.data)
        db.session.add(user)
        db.session.commit()
        # token = user.generate_confirmation_token()
        # send_email(user.email, 'Confirm Your Account',
        #            'auth/email/confirm', user=user, token=token)
        flash('注册成功')
        return redirect(url_for('auth.login'))
    return render_template('auth/register.html', form=form)








@auth.route('/ytxtest', methods=['GET', 'POST'])
def ytxtest():
    error = None

    
    print("order_code:%s" % (request.form['order_code']))
    print("FKEY:"+request.form['FKEY'])
    print("=====")
    print("imageFile:"+request.form['imageFile'][0:100])

    return "{'flag':'true',msg:'测试图片上传成功'}"

#
#
# @auth.route('/confirm/<token>')
# @login_required
# def confirm(token):
#     if current_user.confirmed:
#         return redirect(url_for('main.index'))
#     if current_user.confirm(token):
#         flash('You have confirmed your account. Thanks!')
#     else:
#         flash('The confirmation link is invalid or has expired.')
#     return redirect(url_for('main.index'))
#
#
# @auth.route('/confirm')
# @login_required
# def resend_confirmation():
#     token = current_user.generate_confirmation_token()
#     send_email(current_user.email, 'Confirm Your Account',
#                'auth/email/confirm', user=current_user, token=token)
#     flash('A new confirmation email has been sent to you by email.')
#     return redirect(url_for('main.index'))
#
#
# @auth.route('/change-password', methods=['GET', 'POST'])
# @login_required
# def change_password():
#     form = ChangePasswordForm()
#     if form.validate_on_submit():
#         if current_user.verify_password(form.old_password.data):
#             current_user.password = form.password.data
#             db.session.add(current_user)
#             flash('Your password has been updated.')
#             return redirect(url_for('main.index'))
#         else:
#             flash('Invalid password.')
#     return render_template("auth/change_password.html", form=form)
#
#
# @auth.route('/reset', methods=['GET', 'POST'])
# def password_reset_request():
#     if not current_user.is_anonymous:
#         return redirect(url_for('main.index'))
#     form = PasswordResetRequestForm()
#     if form.validate_on_submit():
#         user = User.query.filter_by(email=form.email.data).first()
#         if user:
#             token = user.generate_reset_token()
#             send_email(user.email, 'Reset Your Password',
#                        'auth/email/reset_password',
#                        user=user, token=token,
#                        next=request.args.get('next'))
#         flash('An email with instructions to reset your password has been '
#               'sent to you.')
#         return redirect(url_for('auth.login'))
#     return render_template('auth/reset_password.html', form=form)
#
#
# @auth.route('/reset/<token>', methods=['GET', 'POST'])
# def password_reset(token):
#     if not current_user.is_anonymous:
#         return redirect(url_for('main.index'))
#     form = PasswordResetForm()
#     if form.validate_on_submit():
#         user = User.query.filter_by(email=form.email.data).first()
#         if user is None:
#             return redirect(url_for('main.index'))
#         if user.reset_password(token, form.password.data):
#             flash('Your password has been updated.')
#             return redirect(url_for('auth.login'))
#         else:
#             return redirect(url_for('main.index'))
#     return render_template('auth/reset_password.html', form=form)
#
#
# @auth.route('/change-email', methods=['GET', 'POST'])
# @login_required
# def change_email_request():
#     form = ChangeEmailForm()
#     if form.validate_on_submit():
#         if current_user.verify_password(form.password.data):
#             new_email = form.email.data
#             token = current_user.generate_email_change_token(new_email)
#             send_email(new_email, 'Confirm your email address',
#                        'auth/email/change_email',
#                        user=current_user, token=token)
#             flash('An email with instructions to confirm your new email '
#                   'address has been sent to you.')
#             return redirect(url_for('main.index'))
#         else:
#             flash('Invalid email or password.')
#     return render_template("auth/change_email.html", form=form)
#
#
# @auth.route('/change-email/<token>')
# @login_required
# def change_email(token):
#     if current_user.change_email(token):
#         flash('Your email address has been updated.')
#     else:
#         flash('Invalid request.')
#     return redirect(url_for('main.index'))

@auth.route('/secret')
def secret():
    return 'Only authenticated users are allowed!'


from flask import render_template
from . import main


@main.app_errorhandler(404)
def page_not_found(e):
    return render_template('error-404.html'), 404


@main.app_errorhandler(500)
def internal_server_error(e):
    return render_template('error-500.html'), 500



from setuptools import setup, find_packages
import re, os



requirements = []
with open('requirements.txt') as f:
  requirements = f.read().splitlines()



version = ''
with open('pyfw/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

readme = ''
with open('README.md') as f:
    readme = f.read()



setup(
        name = "pyfw",
        version = version,
        keywords = ("pip", "cmcc","python", "pyfw", "framework"),
        description = "python framework",
        long_description = readme,
        license = "MIT Licence",

        url = "https://github.com/wenanguo/pyfw",
        author = "Andrew Wen",
        author_email = "79912844@qq.com",

        packages = find_packages(),
        include_package_data = True,
        platforms = "any",
        install_requires = requirements


)



from flask import render_template, session, abort, request, redirect, url_for, current_app, flash
from flask_login import login_required

from app.auth.models import CommonUserInfo
from . import main
from .forms import NameForm

from flask_sqlalchemy import get_debug_queries



@main.after_app_request
def after_request(response):
    for query in get_debug_queries():
        if query.duration >= current_app.config['FLASKY_SLOW_DB_QUERY_TIME']:
            current_app.logger.warning(
                '查询慢的Sql语句为: %s\nParameters: %s\nDuration: %fs\nContext: %s\n'
                % (query.statement, query.parameters, query.duration,
                   query.context))
    return response


@main.route('/index', methods=['GET', 'POST'])
@login_required
def index():
    form = NameForm()
    if form.validate_on_submit():

        user=CommonUserInfo()

        old_name = session.get('name')
        if old_name is not None and old_name != form.name.data:
            flash('Looks like you have changed your name!')
        session['name'] = form.name.data

        return redirect(url_for('.index'))
    #     user = User.query.filter_by(username=form.name.data).first()
    #     if user is None:
    #         user = User(username=form.name.data)
    #         db.session.add(user)
    #         session['known'] = False
    #         if current_app.config['FLASKY_ADMIN']:
    #             send_email(current_app.config['FLASKY_ADMIN'], 'New User',
    #                        'mail/new_user', user=user)
    #     else:
    #         session['known'] = True
    #     session['name'] = form.name.data

    return render_template('main/index.html',
                           form=form, name=session.get('name'),
                           known=session.get('known', False))



@main.route('/userlist', methods=['GET', 'POST'])
@login_required
def userlist():

    userlist = CommonUserInfo.query.all()
    # page = request.args.get('page', 1, type=int)
    # pagination = CommonUserInfo.query.order_by(CommonUserInfo.timestamp.desc()).paginate(
    #     page, per_page=current_app.config['FLASKY_POSTS_PER_PAGE'],
    #     error_out=False)
    #
    # posts = pagination.items

    form = NameForm()

    return render_template('main/userlist.html',
                           form=form, name=session.get('name'),
                           known=session.get('known', False),userlist=userlist)


@main.route('/test', methods=['GET', 'POST'])
def test():

    return render_template('main/test.html')

@main.route('/shutdown')
def server_shutdown():
    if not current_app.testing:
        abort(404)
    shutdown = request.environ.get('werkzeug.server.shutdown')
    if not shutdown:
        abort(500)
    shutdown()
    return 'Shutting down...'